==> plot_window-0.0.50.tar.gz: lib/line.dart <==
part of plot_window;

class LineType {
  String name;
  bool hasLines;
  bool hasPoints;


  String toString()=>this.name;
  
  static List<LineType> LineTypes = new List<LineType>();
  
  static LineType LINEPOINTS = new LineType._intern("linepoints", true, true);
  static LineType POINTS = new LineType._intern("points", false, true);
  static LineType LINE = new LineType._intern("line", true, false);
  static bool Exists(String s)=>LineTypes.where((LineType lt)=>lt.name==s).isNotEmpty;
  
  LineType._intern(this.name, this.hasLines, this.hasPoints) {
  }

  static Init() {
    LineTypes = [LINEPOINTS, POINTS, LINE ];
  }

  static LineType GetLineType(String s) {
    return LineTypes.singleWhere((LineType lt)=>lt.name==s);
  }
  
}


class Line implements Performable {

  String name;
  PointList pointList;
  PointList _validPointList;
  PointList get validPointList => _validPointList;
  PointList _smoothedPointList;

  AverageMethod _cam;
  int _pswidth;
  PointList get smoothedPointList {
    if (_smoothedPointList==null || _cam!=smoother.averageMethod || _pswidth!=smoother.width) {
      _pswidth=smoother.width;
      _cam = smoother.averageMethod;
      _smoothedPointList = _validPointList.smooth(smoother);
    }
    return _smoothedPointList;
  }
  
  PointSmoother _smoother = new PointSmoother(AverageMethod.ARITHMETIC, 0);
  PointSmoother get smoother=>_smoother;
  
  bool showLinearRegression = false;
  String linearRegressionFormat = "###0.00#";
  bool get cropLinearRegression => this.smoothedPointList.cropLinearRegression;
  
  Color _color;
  Color get color=>_color;
  //  Color get color=>_color!=null? _color: Color.BLACK;
  void set color(Color c) {
    _color = c;
  }

  bool operator==(Line other)=>this.name==other.name;

  Performer get performer {
    SettingsGroup sg = new SettingsGroup(this.name)
      ..addPerformer(new StringSetting("Name", this.name, (String str) {this.name=str;}))
      ..addPerformer(new NumSetting("Width", this.width, (num n) { this.width=n;}))
      ..addPerformer(new NumSetting("Point radius", this.pointRadius, (num n) { this.pointRadius=n;}))
      ..addPerformer(new BoolSetting("Show linear regression", this.showLinearRegression, (bool b) {this.showLinearRegression = b; }))
      ..addPerformer(new StringSetting("Linear regression format (# = optional place, 0 = fixed place)", this.linearRegressionFormat, (String s) { this.linearRegressionFormat = s; }))
      ..addPerformer(new BoolSetting("Crop linear regression to window", this.smoothedPointList.cropLinearRegression, (bool b) { this.smoothedPointList.cropLinearRegression = b; }))
      ..addPerformer(new DataListSetting("Line type", this.lineType, LineType.LineTypes, (String s) {
        if (LineType.Exists(s)) {
          this.lineType = LineType.GetLineType(s);
        }}))
      ..addPerformer(smoother.performer);
//    ..populate(smoother);
    return sg;
  }

  num width;
  LineType lineType = LineType.LINEPOINTS;
  num pointRadius = 2;
  AxisType axisType;

  Iterable<num> get _xVals =>_validPointList.points.map((Point p)=>p.x);
  Iterable<num> get _yVals => validPointList.points.map((Point p)=>p.y);
  num get minX=>_xVals.reduce(math.min); //(value, element)=>element>value?value:element);
  num get maxX=>_xVals.reduce(math.max); //(value, element)=>element>value?element:value);
  num get minY=>_yVals.reduce(math.min); //(value, element)=>element>value?value:element);
  num get maxY=>_yVals.reduce(math.max); //(value, element)=>element>value?element:value);

  Rectangle get rectangle=>new Rectangle.fromPoints(new Point(minX, minY), new Point(maxX, maxY));
  

  Line(this.name, this.pointList, {LineType lineType:null, Color color:null, num width:1, AxisType axisType:null}) {
    if(this.pointList==null) { throw "pointList null"; }
    this._validPointList=new PointList(this.pointList.points.where(PlotWindow.ValidPointForCanvas).toList());
    if (lineType != null) this.lineType = lineType;
    this.color = color;
                         
    this.width = width;
    if (axisType==null || axisType==AxisType.X) axisType=AxisType.Y;
    this.axisType = axisType;
  }
}

==> plot_window-0.0.52.tar.gz: lib/line.dart <==
part of plot_window;

class LineType {
  String name;
  bool hasLines;
  bool hasPoints;


  String toString()=>this.name;
  
  static List<LineType> LineTypes = new List<LineType>();
  
  static LineType LINEPOINTS = new LineType._intern("linepoints", true, true);
  static LineType POINTS = new LineType._intern("points", false, true);
  static LineType LINE = new LineType._intern("line", true, false);
  static bool Exists(String s)=>LineTypes.where((LineType lt)=>lt.name==s).isNotEmpty;
  
  LineType._intern(this.name, this.hasLines, this.hasPoints) {
  }

  static Init() {
    LineTypes = [LINEPOINTS, POINTS, LINE ];
  }

  static LineType GetLineType(String s) {
    return LineTypes.singleWhere((LineType lt)=>lt.name==s);
  }
  
}


class Line implements Performable {

  String name;
  PointList pointList;
  PointList _validPointList;
  PointList get validPointList => _validPointList;
  PointList _smoothedPointList;

  AverageMethod _averageMethod;
  int _pswidth;
  PointList get smoothedPointList {
    if (_smoothedPointList==null || _averageMethod!=smoother.averageMethod || _pswidth!=smoother.width) {
      _pswidth=smoother.width;
      _averageMethod = smoother.averageMethod;
      _smoothedPointList = new PointList(smoother.smooth(_validPointList.points)); //_validPointList.smooth(smoother);
    }
    return _smoothedPointList;
  }
  
  PointSmoother _smoother = new PointSmoother(AverageMethod.ARITHMETIC, 0);
  PointSmoother get smoother=>_smoother;
  
  bool showLinearRegression = false;
  String linearRegressionFormat = "###0.00#";

  void set range(Range range) { this.smoothedPointList.range = range; }
  LinearRegression get linearRegression {
    this.smoothedPointList.lrFormat = linearRegressionFormat;
    return this.smoothedPointList.linearRegression;
  }
  
  bool get cropLinearRegression => this.smoothedPointList.cropLinearRegression;
  Range pickRange(Range fixedRange, Range croppedRange) => this.smoothedPointList.pickRange(fixedRange, croppedRange);

  
  Color _color;
  Color get color=>_color;
  void set color(Color c) {
    _color = c;
  }

  bool operator==(Line other)=>this.name==other.name;

  Performer get performer {
    SettingsGroup sg = new SettingsGroup(this.name)
      ..addPerformer(new StringSetting("Name", this.name, (String str) {this.name=str;}))
      ..addPerformer(new NumSetting("Width", this.width, (num n) { this.width=n;}))
      ..addPerformer(new NumSetting("Point radius", this.pointRadius, (num n) { this.pointRadius=n;}))
      ..addPerformer(new BoolSetting("Show linear regression", this.showLinearRegression, (bool b) {this.showLinearRegression = b; }))
      ..addPerformer(new StringSetting("Linear regression format (# = optional place, 0 = fixed place)", this.linearRegressionFormat, (String s) { this.linearRegressionFormat = s; }))
      ..addPerformer(new BoolSetting("Crop linear regression to window", this.smoothedPointList.cropLinearRegression, (bool b) { this.smoothedPointList.cropLinearRegression = b; }))
      ..addPerformer(new DataListSetting("Line type", this.lineType, LineType.LineTypes, (String s) {
        if (LineType.Exists(s)) {
          this.lineType = LineType.GetLineType(s);
        }}))
      ..addPerformer(smoother.performer);
    return sg;
  }

  num width;
  LineType lineType = LineType.LINEPOINTS;
  num pointRadius = 2;
  AxisType axisType;

  Iterable<num> get _xVals =>_validPointList.points.map((Point p)=>p.x);
  Iterable<num> get _yVals => validPointList.points.map((Point p)=>p.y);
  num get minX=>_xVals.reduce(math.min);
  num get maxX=>_xVals.reduce(math.max);
  num get minY=>_yVals.reduce(math.min);
  num get maxY=>_yVals.reduce(math.max);

  Rectangle get rectangle=>new Rectangle.fromPoints(new Point(minX, minY), new Point(maxX, maxY));
  

  Line(this.name, this.pointList, {LineType lineType:null, Color color:null, num width:1, AxisType axisType:null}) {
    if(this.pointList==null) { throw "pointList null"; }
    this._validPointList=new PointList(this.pointList.points.where(PlotWindow.ValidPointForCanvas).toList());
    if (lineType != null) this.lineType = lineType;
    this.color = color;
                         
    this.width = width;
    if (axisType==null || axisType==AxisType.X) axisType=AxisType.Y;
    this.axisType = axisType;
  }
}
